pyDataMover
**************

Move Data fast, perhaps even at warp speed.

pyDataMover is a wrapper and server around the DataMover library, which is a hevaly modified fork of the Facebook WDT library.

The DataMover library is an embeddedable library aiming to
transfer data as fast as possible.

The pyDataMover module aims to provide the following...

- Retain all DataMover performance, minimal Python -> C++ or C++ -> Python calls..
- Low level access to functions and Class'.
- High level helper classes with reasonable default options, with the ability to override all options.
- Optional progress callback.
- Optional logging callback so python handles all logging (Currently in progress)

Installation
============

Comming soon


Documentation
==========================



License
==========================

pyDataMover is provided under a BSD-style license that can be found in the LICENSE file. By using, distributing, or contributing to this project, you agree to the
terms and conditions of this license.

Testing
==========================

```python
import python_example
python_example.add(1, 2)
```

